@@ -13,8 +13,11 @@ Getting Started
 from .market_data import MarketData
 from .forward_curves import ForwardCurves
 from .ewindow_md import EWindowMarketData
+from .wos import WorldOilSupply
+from .wrd import WorldRefineryData
 from .api_client import get_token
-from .types import *
+from .epf import EnergyPriceForecast
+from .insights import Insights
 
 from .config import username, password, set_credentials, appkey, version
 
@@ -29,5 +32,9 @@ __all__ = [
     "set_credentials",
     "ForwardCurves",
     "EWindowMarketData",
+    "WorldOilSupply",
+    "WorldRefineryData",
     "get_token",
+    "EnergyPriceForecast",
+    "Insights",
 ]
