@@ -87,7 +87,7 @@ def get_data(
     include_auth_header: bool = True,
 ) -> Union[DataFrame, requests.Response]:
     url = f"{spgci.config.base_url}/{path}"
-    response = _get(url, params=params, include_auth_header=False)
+    response = _get(url, params=params, include_auth_header=include_auth_header)
 
     if raw:
         if paginate:
