@@ -82,14 +82,14 @@ class Insights:
 
         if strip_html:
             if "headline" in df.columns:
-                df["headline"] = df["headline"].str.replace(r"<.*?>", "", regex=True)  # type: ignore
-                df["headline"] = df["headline"].apply(lambda s: html.unescape(s).replace("\n", " "))  # type: ignore
+                df["headline"] = df["headline"].str.replace(r"<.*?>", " ", regex=True)  # type: ignore
+                df["headline"] = df["headline"].apply(lambda s: html.unescape(str(s)).replace("\n", " "))  # type: ignore
             if "body" in df.columns:
-                df["body"] = df["body"].str.replace(r"<.*?>", "", regex=True)  # type: ignore
-                df["body"] = df["body"].apply(lambda s: html.unescape(s).replace("\n", " "))  # type: ignore
+                df["body"] = df["body"].str.replace(r"<.*?>", " ", regex=True)  # type: ignore
+                df["body"] = df["body"].apply(lambda s: html.unescape(str(s)).replace("\n", " "))  # type: ignore
             if "lead" in df.columns:
-                df["lead"] = df["lead"].str.replace(r"<.*?>", "", regex=True)  # type: ignore
-                df["lead"] = df["lead"].apply(lambda s: html.unescape(s).replace("\n", " "))  # type: ignore
+                df["lead"] = df["lead"].str.replace(r"<.*?>", " ", regex=True)  # type: ignore
+                df["lead"] = df["lead"].apply(lambda s: html.unescape(str(s)).replace("\n", " "))  # type: ignore
 
         return df
 
