@@ -190,6 +190,11 @@ class MarketData:
         assess_date_lte: Optional[date] = None,
         assess_date_gt: Optional[date] = None,
         assess_date_gte: Optional[date] = None,
+        modified_date: Optional[date] = None,
+        modified_date_lt: Optional[date] = None,
+        modified_date_lte: Optional[date] = None,
+        modified_date_gt: Optional[date] = None,
+        modified_date_gte: Optional[date] = None,
         filter_exp: Optional[str] = None,
         page: int = 1,
         page_size: int = 10000,
@@ -218,6 +223,16 @@ class MarketData:
             filter by ``assessDate > x``, by default None
         assess_date_gte : Optional[date], optional
             filter by ``assessDate >= x``, by default None
+        modified_date : Optional[date], optional
+            filter by ``modDate = x`` , by default None
+        modified_date_lt: Optional[date], optional
+            filter by ``modDate < x``, by default None
+        modified_date_lte : Optional[date], optional
+            filter by ``modDate <= x``, by default None
+        modified_date_gt : Optional[date], optional
+            filter by ``modDate > x``, by default None
+        modified_date_gte : Optional[date], optional
+            filter by ``modDate >= x``, by default None
         filter_exp : Optional[str], optional
             pass-thru ``filter`` query param to use a handcrafted filter expression, by default None
         page : int, optional
@@ -266,6 +281,17 @@ class MarketData:
         if assess_date_lte != None:
             filter_params.append(f'assessDate <= "{assess_date_lte}"')
 
+        if modified_date != None:
+            filter_params.append(f'modDate: "{modified_date}"')
+        if modified_date_gt != None:
+            filter_params.append(f'modDate > "{modified_date_gt}"')
+        if modified_date_gte != None:
+            filter_params.append(f'modDate >= "{modified_date_gte}"')
+        if modified_date_lt != None:
+            filter_params.append(f'modDate < "{modified_date_lt}"')
+        if modified_date_lte != None:
+            filter_params.append(f'modDate <= "{modified_date_lte}"')
+
         filter_params = [fp for fp in filter_params if fp != ""]
 
         if filter_exp is None:
@@ -368,6 +394,11 @@ class MarketData:
         assess_date_lte: Optional[date] = None,
         assess_date_gt: Optional[date] = None,
         assess_date_gte: Optional[date] = None,
+        modified_date: Optional[date] = None,
+        modified_date_lt: Optional[date] = None,
+        modified_date_lte: Optional[date] = None,
+        modified_date_gt: Optional[date] = None,
+        modified_date_gte: Optional[date] = None,
         bate: Optional[Union[list[str], "Series[str]", str]] = None,
         filter_exp: Optional[str] = None,
         page: int = 1,
@@ -395,6 +426,16 @@ class MarketData:
             filter by ``assessDate > x``, by default None
         assess_date_gte : Optional[date], optional
             filter by ``assessDate >= x``, by default None
+        modified_date : Optional[date], optional
+            filter by ``modDate = x`` , by default None
+        modified_date_lt: Optional[date], optional
+            filter by ``modDate < x``, by default None
+        modified_date_lte : Optional[date], optional
+            filter by ``modDate <= x``, by default None
+        modified_date_gt : Optional[date], optional
+            filter by ``modDate > x``, by default None
+        modified_date_gte : Optional[date], optional
+            filter by ``modDate >= x``, by default None
         bate : Union[list[str], Series[str], str], optional
             filter by bate, by default []
         filter_exp : Optional[str], optional
@@ -441,6 +482,17 @@ class MarketData:
         if assess_date_lte != None:
             filter_params.append(f'assessDate <= "{assess_date_lte}"')
 
+        if modified_date != None:
+            filter_params.append(f'modDate: "{modified_date}"')
+        if modified_date_gt != None:
+            filter_params.append(f'modDate > "{modified_date_gt}"')
+        if modified_date_gte != None:
+            filter_params.append(f'modDate >= "{modified_date_gte}"')
+        if modified_date_lt != None:
+            filter_params.append(f'modDate < "{modified_date_lt}"')
+        if modified_date_lte != None:
+            filter_params.append(f'modDate <= "{modified_date_lte}"')
+
         filter_params = [fp for fp in filter_params if fp != ""]
 
         if filter_exp is None:
