@@ -21,6 +21,7 @@ class WorldRefineryData:
     ``get_runs()`` to get annual crude runs for individual refineries.
     ``get_yields()`` to get the yields for individual refineries.
     ``get_outages()`` to get refinery outages.
+    ``get_outage_alerts()`` to get intra-day refinery outages.
     ``get_ownership()`` to get refinery ownership.
     ``get_margins()`` to get margin data.
     """
@@ -571,13 +572,14 @@ class WorldRefineryData:
         paginate: bool = False,
         raw: bool = False,
     ) -> Union[Response, DataFrame]:
-        """_summary_
+        """
+        Fetch intra-day refinery outages.
 
         Parameters
         ----------
-        outage_id : Optional[Union[int, list[int], &quot;Series[int]&quot;]], optional
+        outage_id : Optional[Union[int, list[int], Series[int]]], optional
             filter by outageId, by default None
-        created_date : Optional[Union[date, list[date], &quot;Series[date]&quot;]], optional
+        created_date : Optional[Union[date, list[date], Series[date]]], optional
             _description_, by default None
         created_date_gt : Optional[date], optional
             _description_, by default None
@@ -587,15 +589,15 @@ class WorldRefineryData:
             _description_, by default None
         created_date_lte : Optional[date], optional
             _description_, by default None
-        refinery_id : Optional[Union[int, list[int], &quot;Series[int]&quot;]], optional
+        refinery_id : Optional[Union[int, list[int], Series[int]]], optional
             filter by refineryId, by default None
-        operator : Optional[Union[str, list[str], &quot;Series[str]&quot;]], optional
+        operator : Optional[Union[str, list[str], Series[str]]], optional
             filter by operatorname, by default None
-        planning_status : Optional[Union[str, list[str], &quot;Series[str]&quot;]], optional
+        planning_status : Optional[Union[str, list[str], Series[str]]], optional
             filter by planningStatus, by default None
-        country : Optional[Union[str, list[str], &quot;Series[str]&quot;]], optional
+        country : Optional[Union[str, list[str], Series[str]]], optional
             filter by countryName, by default None
-        process_unit : Optional[Union[str, list[str], &quot;Series[str]&quot;]], optional
+        process_unit : Optional[Union[str, list[str], Series[str]]], optional
             filter by processUnitName, by default None
         outage_vol : Optional[Union[float, list[float], Series[float]]], optional
             filter by ``OutageVol_MBD = x`` , by default None
